Learn R Programming

turner (version 0.1.5)

list_ones: List with vectors of ones

Description

Create a list with vectors of ones from a numeric vector

Usage

list_ones(x)

Arguments

x
a numeric vector

Value

  • A list of vectors with ones

See Also

listify

Examples

Run this code
# let's say you have a numeric vector like this
num_vec = c(2, 3, 1, 4)

# get indices in vector format
list_ones(num_vec)

Run the code above in your browser using DataLab